<template>
  <a-card :bordered='false'>
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :md='6' :sm='8'>
            <a-form-item label='仪器名称' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>

              <a-select placeholder='请选择仪器名称' v-model='queryParam.instrument' @change='instrumentChange'>
                <a-select-option v-for='(item,index) in equList' :key='index' :value='item.id'>
                  {{ item.name }}
                </a-select-option>
              </a-select>

            </a-form-item>
          </a-col>
          <a-col :md='6' :sm='8'>
            <a-form-item label='使用类型' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>

              <a-select placeholder='请选择使用类型' v-model='queryParam.useType'>
                <a-select-option :value='1'>
                  临时使用
                </a-select-option>
                <a-select-option :value='2'>
                  预约使用
                </a-select-option>
              </a-select>

            </a-form-item>
          </a-col>
          <a-col :md='6' :sm='8'>
            <a-form-item label='使用人' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>
              <a-select placeholder='请选择使用人' v-model='queryParam.createBy'>
                <a-select-option v-for='(item,index) in userList' :key='index' :value='item.username'>
                  {{ item.realname }}
                </a-select-option>
              </a-select>
            </a-form-item>
          </a-col>
          <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
            <a-col :md='6' :sm='24'>
              <a-button type='primary' @click='searchQuery'>查询</a-button>
              <a-button style='margin-left: 8px' @click='searchReset'>重置</a-button>
            </a-col>
          </span>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button @click='handleAdd' type='primary' icon='plus'>新增</a-button>
      <a-button type='primary' icon='download' @click="handleExportXls('仪器使用记录')">导出</a-button>
      <a-upload name='file' :showUploadList='false' :multiple='false' :headers='tokenHeader' :action='importExcelUrl'
                @change='handleImportExcel'>
        <a-button type='primary' icon='import'>导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList='superFieldList' ref='superQueryModal'
                     @handleSuperQuery='handleSuperQuery'></j-super-query>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

        <template slot='customRenderUseType' slot-scope='text, record'>
          <a-tag v-if='text==2' color='green'>预约使用</a-tag>
          <a-tag v-else>临时使用</a-tag>
        </template>
        <template slot='customRenderFinish' slot-scope='text, record'>
          <a-tag v-if='record.updateTime' color='green'>已完成</a-tag>
          <a-tag v-else color='orange'>未完成</a-tag>
        </template>

      </a-table>
    </div>
    <!-- table区域-end -->



    <lims-usage-record-modal ref='modalForm' @ok='modalFormOk'></lims-usage-record-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LimsUsageRecordModal from './modules/LimsUsageRecordModal'
import { getAction } from '@api/manage'
import moment from 'moment'
import * as echarts from 'echarts'

export default {
  name: 'LimsUsageRecordList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    LimsUsageRecordModal
  },

  data() {
    return {
      description: '仪器使用记录管理页面',
      equList: [],
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '仪器名称',
          align: 'center',
          dataIndex: 'limsInstrument.name'
        },
        {
          title: '使用类型',
          align: 'center',
          dataIndex: 'useType',
          scopedSlots: { customRender: 'customRenderUseType' }
        },
        {
          title: '预约时间',
          align: 'center',
          dataIndex: 'limsAppointmentOption.name'
        },
        {
          title: '使用时长',
          align: 'center',
          dataIndex: 'useTimeStr'
        },
        {
          title: '状态',
          align: 'center',
          scopedSlots: { customRender: 'customRenderFinish' }


        },
        {
          title: '使用日期',
          align: 'center',
          dataIndex: 'createTime',
          customRender(text) {
            return moment(text).format('YYYY-MM-DD')
          }
        },
        {
          title: '使用人',
          align: 'center',
          dataIndex: 'createBy_dictText'
        },
        {
          title: '部门',
          align: 'center',
          dataIndex: 'depart'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/limsUsageRecord/list',
        delete: '/limsUsageRecord/delete',
        deleteBatch: '/limsUsageRecord/deleteBatch',
        exportXlsUrl: '/limsUsageRecord/exportXls',
        importExcelUrl: 'lims/limsUsageRecord/importExcel'

      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
    this.queryEquList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    },
    userList() {
      var userList = []
      this.dataSource.forEach(item => {
        if (userList.find(i => i.username === item.createBy) === undefined) {
          var user = {}
          user.username = item.createBy
          user.realname = item.createBy_dictText
          userList.push(user)
        }
      })
      return userList
    }
  },
  methods: {
    //计算所用时间
    calcTime(str1, str2) {
      var date1 = new Date(str1)
      var date2 = new Date(str2)

      var s1 = date1.getTime(), s2 = date2.getTime()
      var total = (s2 - s1) / 1000

      // var day = parseInt(total / (24*60*60));//计算天数
      // var afterDay = total - day*24*60*60;//取得算出天数后剩余的秒数
      // var hour = parseInt(afterDay/(60*60));//计算小时数
      // var afterHour = total - day*24*60*60 - hour*60*60;//取得算出小时数后剩余的秒数
      // var min = parseInt(afterHour/60);//计算整数分
      // var afterMin = total - day*24*60*60 - hour*60*60 - min*60;//取得算出分后剩余的秒数
      if (total >= 60) {
        var hour = parseInt(afterDay / (60 * 60))//计算小时数
        var afterHour = total - hour * 60 * 60
        var min = parseInt(afterHour / 60)//计算整数分
        var afterMin = total - min * 60//取得算出分后剩余的秒数
        return hour + '时' + min + '分' + afterMin + '秒'
      } else {
        return total + '秒'
      }


    },
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      this.superFieldList = fieldList
    },
    instrumentChange(value) {
      console.info(value)

    },
    //查询设备列表
    queryEquList() {
      getAction('/limsInstrument/list').then(res => {
        if (res.success) {
          this.equList = res.result.records
        }

      })
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>